==> ejc-businessplan-impl-3.0.0-20220225.070150-6-sources.jar: com/ejianc/business/record/vo/RecordsubpackagesupplydetailVO.java <==
package com.ejianc.business.record.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 分供管理策划变更记录子表
 * 
 * @author generator
 * 
 */
public class RecordsubpackagesupplydetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 变更主表id
    private java.lang.String sort; // 序号
    private java.lang.String managerContent; // 管理内容
    private java.lang.String managerAim; // 管理目标
    private java.lang.String managerMeasures; // 管理措施
    private java.lang.String personLiable; // 责任人
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date planCompleteTime; // 计划完成时间
    private java.lang.String implementationEffect; // 实施效果
    

    /**
     * 变更主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 变更主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 管理内容
     */
    public java.lang.String getManagerContent() {
        return managerContent;
    }

    /**
     * 管理内容
     */
    public void setManagerContent(java.lang.String managerContent) {
        this.managerContent = managerContent;
    }
    /**
     * 管理目标
     */
    public java.lang.String getManagerAim() {
        return managerAim;
    }

    /**
     * 管理目标
     */
    public void setManagerAim(java.lang.String managerAim) {
        this.managerAim = managerAim;
    }
    /**
     * 管理措施
     */
    public java.lang.String getManagerMeasures() {
        return managerMeasures;
    }

    /**
     * 管理措施
     */
    public void setManagerMeasures(java.lang.String managerMeasures) {
        this.managerMeasures = managerMeasures;
    }
    /**
     * 责任人
     */
    public java.lang.String getPersonLiable() {
        return personLiable;
    }

    /**
     * 责任人
     */
    public void setPersonLiable(java.lang.String personLiable) {
        this.personLiable = personLiable;
    }
    /**
     * 计划完成时间
     */
    public java.util.Date getPlanCompleteTime() {
        return planCompleteTime;
    }

    /**
     * 计划完成时间
     */
    public void setPlanCompleteTime(java.util.Date planCompleteTime) {
        this.planCompleteTime = planCompleteTime;
    }
    /**
     * 实施效果
     */
    public java.lang.String getImplementationEffect() {
        return implementationEffect;
    }

    /**
     * 实施效果
     */
    public void setImplementationEffect(java.lang.String implementationEffect) {
        this.implementationEffect = implementationEffect;
    }
    
}

==> ejc-businessplan-impl-3.0.0-20220630.103634-87-sources.jar: com/ejianc/business/record/vo/RecordsubpackagesupplydetailVO.java <==
package com.ejianc.business.record.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.change.vo.ChangesubpackagesupplydetailVO;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 分供管理策划变更记录子表
 * 
 * @author generator
 * 
 */
public class RecordsubpackagesupplydetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 变更主表id
    private java.lang.String sort; // 序号
    private java.lang.String tid;
    private java.lang.String tpid;
    private java.lang.String managerContent; // 管理内容
    private java.lang.String managerAim; // 管理目标
    private java.lang.String managerMeasures; // 管理措施
    private java.lang.String personLiable; // 责任人
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date planCompleteTime; // 计划完成时间
    private java.lang.String implementationEffect; // 实施效果

    private List<RecordsubpackagesupplydetailVO> children = new ArrayList<>();

    public List<RecordsubpackagesupplydetailVO> getChildren() {
        return children;
    }

    public void setChildren(List<RecordsubpackagesupplydetailVO> children) {
        this.children = children;
    }

    /**
     * 变更主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 变更主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    /**
     * 管理内容
     */
    public java.lang.String getManagerContent() {
        return managerContent;
    }

    /**
     * 管理内容
     */
    public void setManagerContent(java.lang.String managerContent) {
        this.managerContent = managerContent;
    }
    /**
     * 管理目标
     */
    public java.lang.String getManagerAim() {
        return managerAim;
    }

    /**
     * 管理目标
     */
    public void setManagerAim(java.lang.String managerAim) {
        this.managerAim = managerAim;
    }
    /**
     * 管理措施
     */
    public java.lang.String getManagerMeasures() {
        return managerMeasures;
    }

    /**
     * 管理措施
     */
    public void setManagerMeasures(java.lang.String managerMeasures) {
        this.managerMeasures = managerMeasures;
    }
    /**
     * 责任人
     */
    public java.lang.String getPersonLiable() {
        return personLiable;
    }

    /**
     * 责任人
     */
    public void setPersonLiable(java.lang.String personLiable) {
        this.personLiable = personLiable;
    }
    /**
     * 计划完成时间
     */
    public java.util.Date getPlanCompleteTime() {
        return planCompleteTime;
    }

    /**
     * 计划完成时间
     */
    public void setPlanCompleteTime(java.util.Date planCompleteTime) {
        this.planCompleteTime = planCompleteTime;
    }
    /**
     * 实施效果
     */
    public java.lang.String getImplementationEffect() {
        return implementationEffect;
    }

    /**
     * 实施效果
     */
    public void setImplementationEffect(java.lang.String implementationEffect) {
        this.implementationEffect = implementationEffect;
    }
    
}
